==> mc-4.7.5.2.tar.xz: mc-4.7.5.2/src/subshell.h <==
/** \file subshell.h
 *  \brief Header: concurrent shell support
 */

#ifndef MC__SUBSHELL_H
#define MC__SUBSHELL_H

/*** typedefs(not structures) and defined constants **********************************************/

/* Used to distinguish between a normal MC termination and */
/* one caused by typing `exit' or `logout' in the subshell */
#define SUBSHELL_EXIT 128

#ifdef HAVE_SUBSHELL_SUPPORT

/*** enums ***************************************************************************************/

/* State of the subshell; see subshell.c for an explanation */

enum subshell_state_enum
{
    INACTIVE,
    ACTIVE,
    RUNNING_COMMAND
};

/* For the `how' argument to various functions */
enum
{
    QUIETLY,
    VISIBLY
};

/*** structures declarations (and typedefs of structures)*****************************************/

/*** global variables defined in .c file *********************************************************/

/* If using a subshell for evaluating commands this is true */
extern int use_subshell;

/* File descriptor of the pseudoterminal used by the subshell */
extern int subshell_pty;

extern enum subshell_state_enum subshell_state;

/* Holds the latest prompt captured from the subshell */
extern char *subshell_prompt;

extern gboolean update_subshell_prompt;

/*** declarations of public functions ************************************************************/

void init_subshell (void);
int invoke_subshell (const char *command, int how, char **new_dir);
int read_subshell_prompt (void);
void do_update_prompt (void);
void resize_subshell (void);
int exit_subshell (void);
void do_subshell_chdir (const char *directory, gboolean update_prompt, gboolean reset_prompt);
void subshell_get_console_attributes (void);
void sigchld_handler (int sig);

#else /* not HAVE_SUBSHELL_SUPPORT */
#define use_subshell 0
#endif /* HAVE_SUBSHELL_SUPPORT */

/*** inline functions ****************************************************************************/

#endif /* MC__SUBSHELL_H */

==> mc-4.8.8.tar.xz: mc-4.8.8/src/subshell.h <==
/** \file subshell.h
 *  \brief Header: concurrent shell support
 */

#ifndef MC__SUBSHELL_H
#define MC__SUBSHELL_H

/*** typedefs(not structures) and defined constants **********************************************/

/*** enums ***************************************************************************************/

/* State of the subshell; see subshell.c for an explanation */

enum subshell_state_enum
{
    INACTIVE,
    ACTIVE,
    RUNNING_COMMAND
};

/* For the `how' argument to various functions */
enum
{
    QUIETLY,
    VISIBLY
};

/*** structures declarations (and typedefs of structures)*****************************************/

/*** global variables defined in .c file *********************************************************/

extern enum subshell_state_enum subshell_state;

/* Holds the latest prompt captured from the subshell */
extern GString *subshell_prompt;

extern gboolean update_subshell_prompt;

/*** declarations of public functions ************************************************************/

void init_subshell (void);
int invoke_subshell (const char *command, int how, vfs_path_t ** new_dir);
gboolean read_subshell_prompt (void);
void do_update_prompt (void);
gboolean exit_subshell (void);
void do_subshell_chdir (const vfs_path_t * vpath, gboolean update_prompt, gboolean reset_prompt);
void subshell_get_console_attributes (void);
void sigchld_handler (int sig);

/*** inline functions ****************************************************************************/

#endif /* MC__SUBSHELL_H */
